]> git.djapps.eu Git - pkg/ggml/sources/llama.cpp/commitdiff
cuda: fix warnings for unused variable/function (#26688)
authorDavid Friehs <redacted>
Fri, 7 Aug 2026 04:51:56 +0000 (06:51 +0200)
committerGitHub <redacted>
Fri, 7 Aug 2026 04:51:56 +0000 (07:51 +0300)
ggml/src/ggml-cuda/ggml-cuda.cu
ggml/src/ggml-cuda/quantize.cu

index f4b271146cbf41c720cf75f1edfc01c19bd40306..5446b31318957381fa2ff7fb399ecdfe23557b52 100644 (file)
@@ -5209,6 +5209,7 @@ static bool ggml_backend_cuda_device_offload_op(ggml_backend_dev_t dev, const gg
 
 static ggml_backend_event_t ggml_backend_cuda_device_event_new(ggml_backend_dev_t dev) {
 #ifdef GGML_CUDA_NO_PEER_COPY
+    GGML_UNUSED(dev);
     return nullptr;
 #else
     ggml_backend_cuda_device_context * dev_ctx = (ggml_backend_cuda_device_context *)dev->context;
index 2bd9b6262390686b5dfa405a9f37c56681f31720..bcc7723957b5afb03983a158c237873d2b81f17b 100644 (file)
@@ -8,7 +8,6 @@ struct __builtin_align__(32) float8 {
     float x; float y; float z; float w;
     float p; float q; float r; float s;
 };
-#endif
 
 #if CUDART_VERSION >= 12080
 static __device__ __forceinline__ float nvfp4_native_scale_error(
@@ -49,6 +48,7 @@ static __device__ __forceinline__ float nvfp4_native_scale_error(
     return err;
 }
 #endif // CUDART_VERSION >= 12080
+#endif // defined(BLACKWELL_MMA_AVAILABLE)
 
 __launch_bounds__(CUDA_QUANTIZE_BLOCK_SIZE, 1)
 static __global__ void quantize_q8_1(